colour.models.dataset Package — Colour 0.3.0 documentation

# colour.models.dataset Package

## Sub-Modules

- colour.models.dataset.aces_rgb Module
  - ACES RGB Colourspace
- colour.models.dataset.aces_rgb_idt Module
  - ACES RGB Colourspace - Input Device Transform Dataset
- colour.models.dataset.adobe_rgb_1998 Module
  - Adobe RGB 1998 Colourspace
- colour.models.dataset.adobe_wide_gamut_rgb Module
  - Adobe Wide Gamut RGB Colourspace
- colour.models.dataset.alexa_wide_gamut_rgb Module
  - ALEXA Wide Gamut RGB Colourspace
- colour.models.dataset.apple_rgb Module
  - Apple RGB Colourspace
- colour.models.dataset.best_rgb Module
  - Best RGB Colourspace
- colour.models.dataset.beta_rgb Module
  - Beta RGB Colourspace
- colour.models.dataset.c_log Module
  - Canon C-Log Colourspace
- colour.models.dataset.cie_rgb Module
  - CIE RGB Colourspace
- colour.models.dataset.color_match_rgb Module
  - ColorMatch RGB Colourspace
- colour.models.dataset.dci_p3 Module
  - DCI-P3 Colourspace
- colour.models.dataset.don_rgb_4 Module
  - Don RGB 4 Colourspace
- colour.models.dataset.eci_rgb_v2 Module
  - ECI RGB v2 Colourspace
- colour.models.dataset.ekta_space_ps5 Module
  - Ekta Space PS 5 Colourspace
- colour.models.dataset.max_rgb Module
  - Max RGB Colourspace
- colour.models.dataset.ntsc_rgb Module
  - NTSC RGB Colourspace
- colour.models.dataset.pal_secam_rgb Module
  - Pal/Secam RGB Colourspace
- colour.models.dataset.pointer_gamut Module
  - Pointer Gamut
- colour.models.dataset.prophoto_rgb Module
  - ProPhoto RGB Colourspace
- colour.models.dataset.rec_2020 Module
  - Rec. 2020 Colourspace
- colour.models.dataset.rec_709 Module
  - Rec. 709 Colourspace
- colour.models.dataset.russell_rgb Module
  - Russell RGB Colourspace
- colour.models.dataset.s_log Module
  - Sony S-Log Colourspace
- colour.models.dataset.smptec_rgb Module
  - SMPTE-C RGB Colourspace
- colour.models.dataset.srgb Module
  - sRGB Colourspace
- colour.models.dataset.xtreme_rgb Module
  - Xtreme RGB Colourspace

## Module Contents

`colour.models.dataset.` `RGB_COLOURSPACES` = CaseInsensitiveMapping({u'Adobe RGB 1998': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e126d0>, u'Pal/Secam RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e24910>, u'CIE RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1d650>, u'DCI-P3': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1dad0>, u'Xtreme RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e29cd0>, u'C-Log': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1d410>, u'Apple RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e12e90>, u'SMPTE-C RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e297d0>, 'aces': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e12350>, u'Don RGB 4': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1dd10>, u'S-Log': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e29550>, 'adobe1998': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e126d0>, u'Adobe Wide Gamut RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e12810>, u'ACES RGB Proxy 10': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e124d0>, u'Beta RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1d1d0>, u'ProPhoto RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e24bd0>, u'ColorMatch RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1d890>, u'NTSC RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e24690>, u'Best RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1d050>, u'ALEXA Wide Gamut RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e12cd0>, u'ACES RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e12350>, u'Rec. 709': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e24dd0>, u'Max RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e24490>, u'ECI RGB v2': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1dfd0>, u'ACES RGB Proxy 12': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e12510>, u'ACES RGB Log': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e12390>, u'Ekta Space PS 5': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e24290>, u'sRGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e29a50>, u'Rec. 2020': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e29050>, u'Russell RGB': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e29310>, 'prophoto': <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e24bd0>})

  Aggregated RGB colourspaces.

  RGB_COLOURSPACES : dict

  Aliases:

  - ‘aces’: ACES_RGB_COLOURSPACE.name
  - ‘adobe1998’: ADOBE_RGB_1998_COLOURSPACE.name
  - ‘prophoto’: PROPHOTO_RGB_COLOURSPACE.name